.. neurolang documentation master file, created by sphinx-quickstart on Tue Apr 14 10:29:06 2015. You can adapt this file completely to your liking, but it should at least contain the root `toctree` directive.

Welcome to Neurolang's documentation!
=====================================

.. To see how to use it, please refer to the `README file <https://github.com/NeuroLang/neurolang/blob/master/README.md>`_ in the Github repository.


NeuroLang is a probabilistic logic programming system specialised in the analysis of neuroimaging data, but not exclusively determined by it. See our example gallery for some use cases on neuroimaging meta-analysis.

.. list-table::
   :widths: 40 40

   * - .. figure::  /auto_examples/images/thumb/sphx_glr_plot_neurosynth_implementation_thumb.png
          :scale: 100%
          :class: thumbnail
          :target: auto_examples/plot_neurosynth_implementation.html

          :ref:`sphx_glr_auto_examples_plot_neurosynth_implementation.py` .

     - .. figure::  /auto_examples/images/thumb/sphx_glr_plot_sulcal_queries_thumb.png
          :scale: 100%
          :class: thumbnail
          :target: auto_examples/plot_sulcal_queries.html

          :ref:`sphx_glr_auto_examples_plot_sulcal_queries.py` .


Contents:

.. toctree::
   :maxdepth: 1

   install
   tutorial
   auto_examples/index
   api
   tutorial_logic_programming